<?php

/*
 * PAYPAL SUBSCRIPTION MANAGER
 *
 * @package PaypalSubscriptionManager
 * @author  Michael J. Pawlowsky <mikep@mi-software.com>
 * @copyright Copyright &copy; 2005, Ultimate Internet Marketing
 * @version $Id: Config.class.php,v 1.2 2005/09/07 21:14:13 mikep Exp $;
 *
 * Created: Wed Sep 07 07:02:00 EDT 2005 07:02:00
 * Last Modified: $Date: 2005/09/07 21:14:13 $
 * Revision: $Rev:$
 *
 */

class PayPalIPN {


	var $paypal_post_vars;
	var $paypal_response;
	var $url_string;
	var $timeout;

	// error logging info
	var $error_log_file = 'error_log.txt';
	var $error_email = WEBMASTER_EMAIL;



	function PayPalIPN($paypal_post_vars){
		$this->paypal_post_vars = $paypal_post_vars;
		$this->timeout = 120;
		$this->url_string = PAYPAL_URL . '?';
	}



	// sends response back to paypal
	function send_response(){

		// put all POST variables received from Paypal back into a URL encoded string
		foreach($this->paypal_post_vars AS $key => $value)
		{
			// if magic quotes gpc is on, PHP added slashes to the values so we need
			// to strip them before we send the data back to Paypal.
			if( @get_magic_quotes_gpc() )
			{
				$value = stripslashes($value);
			}

			// make an array of URL encoded values
			$values[] = "$key" . "=" . urlencode($value);
		}

		// join the values together into one url encoded string
		$this->url_string .= @implode("&", $values);

		// add paypal cmd variable
		$this->url_string .= "&cmd=_notify-validate";

		$ch = curl_init();
		if(!$ch){
			$this->error_out("CURL not enabled.");
		}
		curl_setopt ($ch, CURLOPT_URL, $this->url_string);
		curl_setopt ($ch, CURLOPT_USERAGENT, "Mozilla/4.0 (compatible; www.mi-software.com; PayPal IPN Class)");
		curl_setopt ($ch, CURLOPT_HEADER, 1);
		curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt ($ch, CURLOPT_FOLLOWLOCATION, 1);
		curl_setopt ($ch, CURLOPT_TIMEOUT, $this->timeout);
		$this->paypal_response = curl_exec ($ch);

		curl_close($ch);

	} // end function send_response()



	// returns true if paypal says the order is good, false if not
	function is_verified()
	{
		if( ereg("VERIFIED", $this->paypal_response) )
		{
			return true;
		}
		else
		{
			return false;
		}

	} // end function is_verified



	// returns the paypal payment status
	function get_payment_status()
	{
		return $this->paypal_post_vars['payment_status'];
	}

	// returns the paypal payment status
	function get_txn_type()
	{
		if(isset($this->paypal_post_vars['txn_type'])){
			return $this->paypal_post_vars['txn_type'];
		} else {
			return('unknown');
		}
	}


	// writes error to logfile, exits script
	function error_out($message)
	{

		$date = date("D M j G:i:s T Y", time());

		// add on the data we sent:
		$message .= "\n\nThe following input was received from (and sent back to) PayPal:\n\n";

		@reset($this->paypal_post_vars);
		while( @list($key,$value) = @each($this->paypal_post_vars) )
		{
			$message .= $key . ':' . " \t$value\n";
		}

		$message .= "\n\n" . $this->url_string . "\n\n" . $this->paypal_response;

		// log to file?
		if( $this->error_log_file )
		{
			$fp = @fopen($this->error_log_file, 'a');
			$message = "$date\n\n" . $message . "\n\n";
			@fputs($fp, $message);
			@fclose($fp);
		}

		// email errors?
		if( $this->error_email )
		{
			$additional_headers = "From: Webmaster <" . WEBMASTER_EMAIL . ">\nReply-To: " . WEBMASTER_EMAIL;
			mail($this->error_email, "[$date] paypal_ipn error", $message, $additional_headers);
		}

		//exit;

	} // end function error_out

} // end class

?>